@@ -1,23 +1,28 @@
 package Git::Raw;
-{
-  $Git::Raw::VERSION = '0.30'; # TRIAL
-}
-
+$Git::Raw::VERSION = '0.34'; # TRIAL
 use strict;
 use warnings;
 
 require XSLoader;
 XSLoader::load('Git::Raw', $Git::Raw::VERSION);
 
+use Git::Raw::Filter;
+use Git::Raw::Reference;
 use Git::Raw::Repository;
 
+=for HTML
+<a href="https://travis-ci.org/ghedo/p5-Git-Raw">
+	<img src="https://travis-ci.org/ghedo/p5-Git-Raw.svg?branch=master" align="right">
+</a>
+=cut
+
 =head1 NAME
 
 Git::Raw - Perl bindings to the Git linkable library (libgit2)
 
 =head1 VERSION
 
-version 0.30
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -33,6 +38,8 @@ B<WARNING>: The API of this module is unstable and may change without warning
 
 Alessandro Ghedini <alexbio@cpan.org>
 
+Jacques Germishuys <jacquesg@striata.com>
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2012 Alessandro Ghedini.
