@@ -1,8 +1,5 @@
 package Git::Raw::Reference;
-{
-  $Git::Raw::Reference::VERSION = '0.30'; # TRIAL
-}
-
+$Git::Raw::Reference::VERSION = '0.34'; # TRIAL
 use strict;
 use warnings;
 
@@ -14,7 +11,7 @@ Git::Raw::Reference - Git reference class
 
 =head1 VERSION
 
-version 0.30
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -46,6 +43,12 @@ afterwards.
 
 Retrieve the name of the reference.
 
+=head2 shorthand( )
+
+Get the reference's short name. This will transform the reference name into a
+"human-readable" version. If no shortname is appropriate, it will return the
+full name.
+
 =head2 type( )
 
 Retrieve the type of the reference. Can be either C<"direct"> or C<"symbolic">.
@@ -62,6 +65,15 @@ This function returns either an object (L<Git::Raw::Blob>, L<Git::Raw::Commit>,
 L<Git::Raw::Tag> or L<Git::Raw::Tree>) for direct references, or another
 reference for symbolic references.
 
+=head2 reflog( )
+
+Retrieve the L<Git::Raw::Reflog> of the reference. Shortcur for
+C<Git::Raw::Reflog-E<gt>open()>.
+
+=cut
+
+sub reflog { return Git::Raw::Reflog -> open (shift); }
+
 =head2 owner( )
 
 Retrieve the L<Git::Raw::Repository> owning the reference.
@@ -74,6 +86,14 @@ Check if the reference is a branch.
 
 Check if the reference is remote.
 
+=head2 is_tag( )
+
+Check if the reference lives in the L<"refs/tags"> namespace.
+
+=head2 is_note( )
+
+Check if the reference lives in the L<"refs/notes"> namespace.
+
 =head1 AUTHOR
 
 Alessandro Ghedini <alexbio@cpan.org>
