@@ -1,8 +1,5 @@
 package Git::Raw::Repository;
-{
-  $Git::Raw::Repository::VERSION = '0.30'; # TRIAL
-}
-
+$Git::Raw::Repository::VERSION = '0.34'; # TRIAL
 use strict;
 use warnings;
 
@@ -14,7 +11,7 @@ Git::Raw::Repository - Git repository class
 
 =head1 VERSION
 
-version 0.30
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -28,7 +25,7 @@ version 0.30
           my ($total_objects, $received_objects, $local_objects, $total_deltas,
             $indexed_deltas, $received_bytes) = @_;
 
-          print "Objects: $received_objects/$total_objecs", "\n";
+          print "Objects: $received_objects/$total_objects", "\n";
           print "Received: ", int($received_bytes/1024), "KB", "\n";
         }
       }
@@ -89,7 +86,7 @@ The callback to be called any time authentication is required to connect to the
 remote repository. The callback receives a string containing the URL of the
 remote, and it must return a L<Git::Raw::Cred> object.
 
-=item * "progress"
+=item * "sideband_progress"
 
 Textual progress from the remote. Text send over the progress side-band will be
 passed to this function (this is the 'counting objects' output). The callback
@@ -103,15 +100,16 @@ Completion is called when different parts of the download process are done
 =item * "transfer_progress"
 
 During the download of new data, this will be regularly called with the current
-count of progress done by the indexer. The callback receives the following integers:
-C<total_objects>, C<received_objects>, C<local_objects>, C<total_deltas>,
-C<indexed_deltas> and C<received_bytes>.
+count of progress done by the indexer. The callback receives the following
+integers: C<total_objects>, C<received_objects>, C<local_objects>,
+C<total_deltas>, C<indexed_deltas> and C<received_bytes>.
 
 =item * "update_tips"
 
 Each time a reference is updated locally, this function will be called with
 information about it. The callback receives a string containing the name of the
-reference that was updated, and the two OID's C<"a"> before and C<"b"> after the update.
+reference that was updated, and the two OID's C<"a"> before and C<"b"> after the
+update.
 
 =back
 
@@ -252,16 +250,17 @@ Hash containg progress and notification callbacks. Valid fields are:
 
 =item * "notify"
 
-This callback is called for each file matching one of the C<notify> options selected.
-It runs before modifying any files on disk. This callback should return a non-zero value
-should the checkout be cancelled.  The callback receives a string containing the path
-of the file C<path> and an array reference containing the reason C<why>.
+This callback is called for each file matching one of the C<notify> options
+selected. It runs before modifying any files on disk. This callback should
+return a non-zero value should the checkout be cancelled.  The callback receives
+a string containing the path of the file C<path> and an array reference
+containing the reason C<why>.
 
 =item * "progress"
 
-The callback to be invoked as a file is checked out. The callback receives a string
-containing the path of the file C<path>, an integer C<completed_steps> and an
-integer C<total_steps>.
+The callback to be invoked as a file is checked out. The callback receives a
+string containing the path of the file C<path>, an integer C<completed_steps>
+and an integer C<total_steps>.
 
 =back
 
@@ -325,9 +324,9 @@ include: C<"index_new">, C<"index_modified">, C<"index_deleted">, C<"index_renam
 C<"worktree_new">, C<"worktree_modified">, C<"worktree_deleted">,
 C<"worktree_renamed"> and C<"ignored">.
 
-If C<$file> has been renamed in either the index or worktree or both, C<$file> will
-also have a corresponding entry C<"index"> and/or C<"worktree">, containing the
-previous filename C<"old_file">.
+If C<$file> has been renamed in either the index or worktree or both, C<$file>
+will also have a corresponding entry C<"index"> and/or C<"worktree">, containing
+the previous filename C<"old_file">.
 
 Example:
 
@@ -347,35 +346,59 @@ Example:
       }
     }
 
-=head2 merge( $ref, \%opts)
+=head2 merge_base( @objects )
+
+Find the merge base between C<@objects>. Each element in C<@objects> should be
+peelable to a C<Git::Raw::Commit> object, that is, it should be a
+C<Git::Raw::Commit> or C<Git::Raw::Reference> object, or alternatively a commit
+id or commit id prefix.
+
+=head2 merge_analysis( $reference )
+
+Analyzes the given C<$reference> and determines the opportunities for merging
+them into the HEAD of the repository. This function returns an array reference
+with optional members C<"normal">, C<"up_to_date">, C<"fast_forward"> and/or
+C<"unborn">.
+
+=over 4
+
+=item * "normal"
+
+A "normal" merge. Both HEAD and the given merge input have diverged from their
+common ancestor. The divergent commits must be merged.
+
+=item * "up_to_date"
+
+All given merge inputs are reachable from HEAD, meaning the repository is
+up-to-date and no merge needs to be performed.
+
+=item * "fast_forward"
+
+The given merge input is a fast-forward from HEAD and no merge needs to be
+performed. Instead, the given merge input may be checked out.
+
+=item * "unborn"
+
+The HEAD of the current repository is "unborn" and does not point to a valid
+commit. No merge can be performed, but the caller may wish to simply set
+HEAD to the target commit(s).
+
+=back
+
+=head2 merge( $ref, [\%merge_opts, \%checkout_opts])
 
 Merge the given C<$ref> into HEAD. This function returns a hash reference
 with members C<"up_to_date">, C<"fast_forward"> and C<"id"> if the merge
-was fast-forward. Valid fields for C<%opts> are
+was fast-forward.  See C<Git::Raw::Repository-E<gt>checkout()> for valid
+C<%checkout_opts> values.  Valid fields for C<%merge_opts> are
 
 =over 4
 
 =item * "flags"
 
-Flags for the merge. Valid values include (mutually exclusive):
-
-=over 8
-
-=item * "fastforward_only"
-
-=item * "no_fastforward"
-
-=back
-
-=item * "tree_opts"
-
-=over 8
-
-=item * "flags"
-
 An array of flags for the tree, including:
 
-=over 12
+=over 8
 
 =item * "find_renames"
 
@@ -383,10 +406,10 @@ Detect renames.
 
 =back
 
-=item * "automerge"
+=item * "favor"
 
-Specify content automerging behavoiur. Valid values are C<"favor_ours"> and
-C<"favor_theirs">.
+Specify content automerging behaviour. Valid values are C<"ours">, C<"theirs">,
+and C<"union">.
 
 =item * "rename_threshold"
 
@@ -399,28 +422,21 @@ configuration entry) (default is 200).
 
 =back
 
-=item * "checkout_opts"
-
-See C<Git::Raw::Repository-E<gt>checkout()>.
-
-=back
-
 Example:
 
-    my $branch  = Git::Raw::Branch -> lookup($repo, 'branch', 1);
-    my $result = $repo -> merge($branch1, {
-      'flags' => {
-        'fastforward_only' => 1
+    my $branch = Git::Raw::Branch -> lookup($repo, 'branch', 1);
+    my $analysis = $repo -> merge_analysis($branch);
+    $repo -> merge($branch1,
+     {
+        'favor' => 'theirs'
+     },
+
+     {
+      'checkout_strategy' => {
+        'force' => 1
       }
-      'tree_opts' => {
-        'automerge' => 'favor_theirs'
-      }
-      'checkout_opts' => {
-        'checkout_strategy' => {
-          'force' => 1
-        }
-      }
-    }
+     }
+    );
 
 =head2 ignore( $rules )
 
@@ -461,6 +477,10 @@ Reverse the sides of the diff.
 
 Include ignored files in the diff.
 
+=item * "include_typechange"
+
+Enable the generation of typechange delta records.
+
 =item * "recurse_ignored_dirs"
 
 Even if C<"include_ignored"> is specified, an entire ignored directory
@@ -481,6 +501,10 @@ This flag adds all files under untracked directories as untracked entries, too.
 
 Ignore file mode changes.
 
+=item * "ignore_case"
+
+Use case insensitive filename comparisons.
+
 =item * "ignore_submodules"
 
 Treat all submodules as unmodified.
@@ -497,6 +521,27 @@ Ignore changes in amount of whitespace.
 
 Ignore whitespace at end of line.
 
+=item * "skip_binary_check"
+
+Disable updating of the binary flag in delta records.
+
+=item * "enable_fast_untracked_dirs"
+
+When diff finds an untracked directory, to match the behavior of core git, it
+scans the contents for ignored and untracked files. If all contents are ignore,
+then the directory is ignored. If any contents are not ignored, then the
+directory is untracked.  This is extra work that may not matter in many cases.
+This flag turns off that scan and immediately labels an untracked directory
+as untracked (changing the behavior to not match core git).
+
+=item * "show_untracked_content"
+
+Include the content of untracked files. This implies L<"include_untracked">.
+
+=item * "show_unmodified"
+
+Include the names of unmodified files.
+
 =item * "patience"
 
 Use the C<"patience diff"> algorithm.
@@ -555,11 +600,12 @@ Create a new L<Git::Raw::Branch>. Shortcut for C<Git::Raw::Branch-E<gt>create()>
 
 sub branch { return Git::Raw::Branch -> create(@_) }
 
-=head2 branches( )
+=head2 branches( [$type] )
 
-Retrieve a list of L<Git::Raw::Branch> objects.
+Retrieve a list of L<Git::Raw::Branch> objects. Possible values for C<$type>
+include L<"local">, L<"remote"> or L<"all">.
 
-=head2 commit( $msg, $author, $committer, [@parents], $tree [, $update_ref ] )
+=head2 commit( $msg, $author, $committer, \@parents, $tree [, $update_ref ] )
 
 Create a new L<Git::Raw::Commit>. Shortcut for C<Git::Raw::Commit-E<gt>create()>.
 
@@ -577,7 +623,8 @@ sub tag { return Git::Raw::Tag -> create(@_) }
 
 =head2 tags( )
 
-Retrieve the list of L<Git::Raw::Tag> objects.
+Retrieve the list of L<Git::Raw::Tag> objects representing the
+repository's annotated Git tags. Lightweight tags are not returned.
 
 =cut
 
@@ -626,6 +673,10 @@ Retrieve the complete path of the repository.
 Retrieve the working directory of the repository. If C<$new_dir> is passed, the
 working directory of the repository will be set to the directory.
 
+=head2 blame( $path )
+
+Retrieve blame information for C<$path>. Returns a C<Git::Raw::Blame> object.
+
 =head2 state( )
 
 Determine the state of the repository. One of the following values is returned:
@@ -679,6 +730,10 @@ Repository is applying patches or rebasing.
 Remove all the metadata associated with an ongoing command like merge, revert,
 cherry-pick, etc.
 
+=head2 message( )
+
+Retrieve the content of git's prepared message i.e. L<".git/MERGE_MSG">.
+
 =head2 is_empty( )
 
 Check if the repository is empty.
@@ -691,10 +746,17 @@ Check if the repository is bare.
 
 Check if the repository is a shallow clone.
 
+=head2 is_head_detached( )
+
+Check if the repository's HEAD is detached, that is, it points directly to
+a commit.
+
 =head1 AUTHOR
 
 Alessandro Ghedini <alexbio@cpan.org>
 
+Jacques Germishuys <jacquesg@striata.com>
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2012 Alessandro Ghedini.
