@@ -1,8 +1,5 @@
 package Git::Raw::Tree;
-{
-  $Git::Raw::Tree::VERSION = '0.30'; # TRIAL
-}
-
+$Git::Raw::Tree::VERSION = '0.34'; # TRIAL
 use strict;
 use warnings;
 
@@ -14,7 +11,7 @@ Git::Raw::Tree - Git tree class
 
 =head1 VERSION
 
-version 0.30
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -36,15 +33,22 @@ Retrieve the id of the tree, as string.
 
 =head2 entries( )
 
-Retrieve a list of L<Git::Raw::TreeEntry> objects.
+Retrieve a list of L<Git::Raw::Tree::Entry> objects.
 
 =head2 entry_byname( $name )
 
-Retrieve a L<Git::Raw::TreeEntry> object by name.
+Retrieve a L<Git::Raw::Tree::Entry> object by name.
 
 =head2 entry_bypath( $path )
 
-Retrieve a L<Git::Raw::TreeEntry> object by path.
+Retrieve a L<Git::Raw::Tree::Entry> object by path.
+
+=head2 merge( $ancestor, $theirs, [\%merge_opts] )
+
+Merge C<$theirs> into this tree. C<$ancestor> and C<$theirs> should be
+C<Git::Raw::Tree> objects.  See C<Git::Raw::Repository-E<gt>merge()> for valid
+C<%merge_opts> values. Returns a C<Git::Raw::Index> object containing the
+merge result.
 
 =head2 diff( [\%opts] )
 
